@@ -20,7 +20,7 @@ use utf8;
 use strict;
 use warnings;
 
-use Convert::Base32 qw(decode_base32);
+use MIME::Base32 qw(decode_base32);
 use Digest::HMAC;
 use Digest::SHA;
 use Math::BigInt;
@@ -29,7 +29,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(otp hotp totp);
 
-our $VERSION = '1.6';
+our $VERSION = '1.801';
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ sub hotp {
     my ($hex) = $C->as_hex =~ /^0x(.*)/;
     $hex = "0" x (16 - length($hex)) . $hex;
 
-    my ($algorithm) = $options{algorithm} =~ /sha(\d+)/;
+    my ($algorithm) = $options{algorithm} =~ /sha(\d+)/i;
     my $digest = Digest::SHA->new($algorithm);
     my $hmac   = Digest::HMAC->new(
         $options{base32} ? decode_base32($options{secret} =~ s/ //gr) : pack('H*', $options{secret}),
